@@ -124,28 +124,28 @@ class MQTTPipeline(object):
                 if self.on_c2d_message_received:
                     self.on_c2d_message_received(event.message)
                 else:
-                    logger.warning("C2D message event received with no handler.  dropping.")
+                    logger.error("C2D message event received with no handler.  dropping.")
 
             elif isinstance(event, pipeline_events_iothub.InputMessageEvent):
                 if self.on_input_message_received:
                     self.on_input_message_received(event.message)
                 else:
-                    logger.warning("input message event received with no handler.  dropping.")
+                    logger.error("input message event received with no handler.  dropping.")
 
             elif isinstance(event, pipeline_events_iothub.MethodRequestEvent):
                 if self.on_method_request_received:
                     self.on_method_request_received(event.method_request)
                 else:
-                    logger.warning("Method request event received with no handler. Dropping.")
+                    logger.error("Method request event received with no handler. Dropping.")
 
             elif isinstance(event, pipeline_events_iothub.TwinDesiredPropertiesPatchEvent):
                 if self.on_twin_patch_received:
                     self.on_twin_patch_received(event.patch)
                 else:
-                    logger.warning("Twin patch event received with no handler. Dropping.")
+                    logger.error("Twin patch event received with no handler. Dropping.")
 
             else:
-                logger.warning("Dropping unknown pipeline event {}".format(event.name))
+                logger.error("Dropping unknown pipeline event {}".format(event.name))
 
         def _on_connected():
             if self.on_connected:
@@ -346,9 +346,7 @@ class MQTTPipeline(object):
 
         def on_complete(op, error):
             if error:
-                logger.warning(
-                    "Subscribe for {} failed.  Not enabling feature".format(feature_name)
-                )
+                logger.error("Subscribe for {} failed.  Not enabling feature".format(feature_name))
             else:
                 self.feature_enabled[feature_name] = True
             callback(error=error)
